@@ -116,21 +116,23 @@ DkImageLoader::DkImageLoader(const QString &filePath)
     qRegisterMetaType<QFileInfo>("QFileInfo");
 
     mDirWatcher = new QFileSystemWatcher(this);
-    connect(mDirWatcher, SIGNAL(directoryChanged(QString)), this, SLOT(directoryChanged(QString)));
+    connect(mDirWatcher, &QFileSystemWatcher::directoryChanged, this, &DkImageLoader::directoryChanged);
 
     mSortingIsDirty = false;
     mSortingImages = false;
 
-    connect(&mCreateImageWatcher, SIGNAL(finished()), this, SLOT(imagesSorted()));
+    connect(&mCreateImageWatcher, &QFutureWatcher<QVector<QSharedPointer<DkImageContainerT>>>::finished, this, &DkImageLoader::imagesSorted);
 
     mDelayedUpdateTimer.setSingleShot(true);
-    connect(&mDelayedUpdateTimer, SIGNAL(timeout()), this, SLOT(directoryChanged()));
+    connect(&mDelayedUpdateTimer, &QTimer::timeout, this, [this]() {
+        directoryChanged();
+    });
 
-    connect(DkActionManager::instance().action(DkActionManager::menu_file_save_copy), SIGNAL(triggered()), this, SLOT(copyUserFile()));
-    connect(DkActionManager::instance().action(DkActionManager::menu_edit_undo), SIGNAL(triggered()), this, SLOT(undo()));
-    connect(DkActionManager::instance().action(DkActionManager::menu_edit_redo), SIGNAL(triggered()), this, SLOT(redo()));
-    connect(DkActionManager::instance().action(DkActionManager::menu_view_gps_map), SIGNAL(triggered()), this, SLOT(showOnMap()));
-    connect(DkActionManager::instance().action(DkActionManager::sc_delete_silent), SIGNAL(triggered()), this, SLOT(deleteFile()), Qt::UniqueConnection);
+    connect(DkActionManager::instance().action(DkActionManager::menu_file_save_copy), &QAction::triggered, this, &DkImageLoader::copyUserFile);
+    connect(DkActionManager::instance().action(DkActionManager::menu_edit_undo), &QAction::triggered, this, &DkImageLoader::undo);
+    connect(DkActionManager::instance().action(DkActionManager::menu_edit_redo), &QAction::triggered, this, &DkImageLoader::redo);
+    connect(DkActionManager::instance().action(DkActionManager::menu_view_gps_map), &QAction::triggered, this, &DkImageLoader::showOnMap);
+    connect(DkActionManager::instance().action(DkActionManager::sc_delete_silent), &QAction::triggered, this, &DkImageLoader::deleteFile, Qt::UniqueConnection);
 
     // saveDir = DkSettingsManager::param().global().lastSaveDir;	// loading save dir is obsolete ?!
 
@@ -161,7 +163,7 @@ void DkImageLoader::clearPath()
 {
     // lastFileLoaded must exist
     if (mCurrentImage && mCurrentImage->exists()) {
-        mCurrentImage->receiveUpdates(this, false);
+        this->receiveUpdates(false);
         mLastImageLoaded = mCurrentImage;
         mImages.clear();
 
@@ -197,7 +199,7 @@ bool DkImageLoader::loadZipArchive(const QString &zipPath)
     QFileInfoList fileInfoList;
     // encode both the input zip file and the output image into a single fileInfo
     for (const QString &filePath : fileList)
-        fileInfoList.append(DkZipContainer::encodeZipFile(zipPath, filePath));
+        fileInfoList.append(QFileInfo(DkZipContainer::encodeZipFile(zipPath, filePath)));
 
     QFileInfo zipInfo(zipPath);
 
@@ -306,6 +308,11 @@ bool DkImageLoader::loadDir(const QString &newDirPath, bool scanRecursive)
     return true;
 }
 
+void DkImageLoader::loadDirRecursive(const QString &newDirPath)
+{
+    this->loadDir(newDirPath, true);
+}
+
 void DkImageLoader::sortImagesThreaded(QVector<QSharedPointer<DkImageContainerT>> images)
 {
     if (mSortingImages) {
@@ -364,11 +371,9 @@ void DkImageLoader::createImages(const QFileInfoList &files, bool sort)
     qInfo() << "[DkImageLoader]" << mImages.size() << "containers created in" << dt;
 
     if (sort) {
-        std::sort(mImages.begin(), mImages.end(), imageContainerLessThanPtr);
+        DkImageLoader::sort();
         qInfo() << "[DkImageLoader] after sorting: " << dt;
 
-        emit updateDirSignal(mImages);
-
         if (mDirWatcher) {
             if (!mDirWatcher->directories().isEmpty())
                 mDirWatcher->removePaths(mDirWatcher->directories());
@@ -379,7 +384,8 @@ void DkImageLoader::createImages(const QFileInfoList &files, bool sort)
 
 QVector<QSharedPointer<DkImageContainerT>> DkImageLoader::sortImages(QVector<QSharedPointer<DkImageContainerT>> images) const
 {
-    std::sort(images.begin(), images.end(), imageContainerLessThanPtr);
+    // this is dead code and could crash, see sort() for a correct way to do it
+    // std::sort(images.begin(), images.end(), imageContainerLessThanPtr);
     return images;
 }
 
@@ -411,12 +417,15 @@ void DkImageLoader::changeFile(int skipIdx)
 }
 
 /**
- * Returns the file info of the ancesting/subsequent file + skipIdx.
- * @param skipIdx the number of files to be skipped from the current file.
- * @param silent if true, no status information will be displayed.
- * @return QFileInfo the file info of the demanded file
+ * Find subsequent file at offset skipIdx
+ * @param skipIdx the number of files to be skipped from the current file
+ * @param recursive true if calling ourself
+ * @param currFileIdx passed to recursive calls to adjust for subfolders
+ * @note If scanFoldersRecursive, then all subfolders (mSubFolders) are checked,
+ *       otherwise only the current folder is considered.
+ * @return
  **/
-QSharedPointer<DkImageContainerT> DkImageLoader::getSkippedImage(int skipIdx, bool searchFile, bool recursive)
+QSharedPointer<DkImageContainerT> DkImageLoader::getSkippedImage(int skipIdx, bool recursive /* = false */, int currFileIdx /* = 0 */)
 {
     QSharedPointer<DkImageContainerT> imgC;
 
@@ -429,104 +438,88 @@ QSharedPointer<DkImageContainerT> DkImageLoader::getSkippedImage(int skipIdx, bo
     if (mCurrentImage->setPageIdx(skipIdx))
         return mCurrentImage;
 
-    // if (searchFile && currentImage->file().absoluteDir() != dir.absolutePath()) {
-    //	qDebug() << "loading new dir: " << currentImage->file().absolutePath();
-    //	qDebug() << "old dir: " << dir.absolutePath();
-
-    if (!recursive)
+    // we need the current file's index, non-trivial if there are file/folder deletions etc
+    // note: the recursive calls are providing this for us
+    if (!recursive) {
+        // we need a valid current dir before we can proceed; it might have been modified
+        // do not scan recursive here since getSkippedImage is called for every scroll and can be slow when recursing
+        // note: the recursive call already did loadDir() so its fine to have this here
+        // note: we don't care if this fails
+        // note: loadDir will not update dir if we renamed or deleted a file, for that to happen,
+        //       mFolderUpdated must also be set
         loadDir(mCurrentImage->dirPath(), false);
 
-    // locate the current file
-    int newFileIdx = 0;
+        // note: this makes no sense so I've disabled it for now
+        // QString file = (mCurrentImage->exists()) ? mCurrentImage->filePath() : mCurrentDir;
+        QString file = mCurrentImage->filePath();
 
-    if (searchFile)
-        mTmpFileIdx = 0;
+        currFileIdx = findFileIdx(file, mImages);
 
-    // qDebug() << "virtual file " << virtualFile.absoluteFilePath();
-    // qDebug() << "file" << file.absoluteFilePath();
+        if (currFileIdx == -1) {
+            // current file was deleted or renamed, externally or by ourself
+            // locate where it would be in sorted order
+            qDebug() << "missing file" << mCurrentImage->filePath();
 
-    // if (virtualExists || file.exists()) {
+            bool sortAscending = DkSettingsManager::param().global().sortDir == DkSettings::sort_ascending;
+            const auto isLessThan = DkImageContainer::compareFunc();
 
-    if (searchFile) {
-        QString file = (mCurrentImage->exists()) ? mCurrentImage->filePath() : mCurrentDir;
-
-        mTmpFileIdx = findFileIdx(file, mImages);
-
-        // could not locate the file -> it was deleted?!
-        if (mTmpFileIdx == -1) {
-            mTmpFileIdx = 0;
-            for (; mTmpFileIdx < mImages.size(); mTmpFileIdx++) {
-                if (*(mCurrentImage.data()) < *(mImages[mTmpFileIdx].data()))
+            currFileIdx = 0;
+            for (; currFileIdx < mImages.size(); currFileIdx++) {
+                if (!sortAscending ^ isLessThan(mCurrentImage, mImages[currFileIdx]))
                     break;
             }
 
             if (skipIdx > 0)
-                mTmpFileIdx--; // -1 because the current file does not exist
-            if (mImages.size() == mTmpFileIdx) // could not locate file - resize
-                mTmpFileIdx = 0;
+                currFileIdx--; // -1 because the current file was dropped
+            if (mImages.size() == currFileIdx) // last one is the closest
+                currFileIdx = mImages.size() - 1;
         }
     }
-    newFileIdx = mTmpFileIdx + skipIdx;
 
-    // qDebug() << "subfolders: " << DkSettingsManager::param().global().scanSubFolders << "subfolder size: " << (subFolders.size() > 1);
+    // new index in the current dir
+    int newFileIdx = currFileIdx + skipIdx;
 
-    if (DkSettingsManager::param().global().scanSubFolders && mSubFolders.size() > 1 && (newFileIdx < 0 || newFileIdx >= mImages.size())) {
-        int folderIdx = 0;
+    // invalid index means we have to loop, search subfolder etc depending on settings
+    bool validIndex = newFileIdx >= 0 && newFileIdx < mImages.size();
 
-        // locate folder
-        for (int idx = 0; idx < mSubFolders.size(); idx++) {
-            if (mSubFolders[idx] == mCurrentDir) {
-                folderIdx = idx;
-                break;
-            }
-        }
+    // search subfolders
+    if (!validIndex && DkSettingsManager::param().global().scanSubFolders && mSubFolders.size() > 1) {
+        int currFolderIdx = mSubFolders.indexOf(mCurrentDir);
+        int newFolderIdx = getSubFolderIdx(currFolderIdx, newFileIdx >= 0);
 
-        if (newFileIdx < 0)
-            folderIdx = getPrevFolderIdx(folderIdx);
-        else
-            folderIdx = getNextFolderIdx(folderIdx);
+        qDebug() << mSubFolders;
+        qDebug() << "new folder idx: " << newFolderIdx;
 
-        qDebug() << "new folder idx: " << folderIdx;
-
-        // if (DkSettingsManager::param().global().loop)
-        //	folderIdx %= subFolders.size();
-
-        if (folderIdx >= 0 && folderIdx < mSubFolders.size()) {
+        if (newFolderIdx < 0) {
+            // not a problem; the subfolder list could all be empty folders
+        } else {
             int oldFileSize = mImages.size();
-            loadDir(mSubFolders[folderIdx], false); // don't scan recursive again
-            qDebug() << "loading new folder: " << mSubFolders[folderIdx];
+
+            qDebug() << "loading subfolder: " << mSubFolders[newFolderIdx];
+            loadDir(mSubFolders.at(newFolderIdx), false); // don't scan recursive again
 
             if (newFileIdx >= oldFileSize) {
-                newFileIdx -= oldFileSize;
-                mTmpFileIdx = 0;
-                qDebug() << "new skip idx: " << newFileIdx << "cFileIdx: " << mTmpFileIdx << " -----------------------------";
-                getSkippedImage(newFileIdx, false, true);
-            } else if (newFileIdx < 0) {
-                newFileIdx += mTmpFileIdx;
-                mTmpFileIdx = mImages.size() - 1;
-                qDebug() << "new skip idx: " << newFileIdx << "cFileIdx: " << mTmpFileIdx << " -----------------------------";
-                getSkippedImage(newFileIdx, false, true);
+                skipIdx -= oldFileSize - currFileIdx; // subtract how many being skipped
+                currFileIdx = 0; // restart at first image in dir
+            } else {
+                skipIdx += currFileIdx + 1; // add how many being skipped
+                currFileIdx = mImages.size() - 1; // restart at last image in dir
             }
-        }
-        //// dir up
-        // else if (folderIdx == subFolders.size()) {
 
-        //	qDebug() << "going one up";
-        //	dir.cd("..");
-        //	loadDir(dir, false);	// don't scan recursive again
-        //	newFileIdx += cFileIdx;
-        //	cFileIdx = 0;
-        //	getChangedFileInfo(newFileIdx, silent, false);
-        //}
-        //// get root files
-        // else if (folderIdx < 0) {
-        //	loadDir(dir, false);
-        // }
+            qDebug() << "new skip idx: " << skipIdx << "cFileIdx: " << currFileIdx << " -----------------------------";
+            return getSkippedImage(skipIdx, true, currFileIdx);
+        }
     }
 
 #ifdef WITH_QUAZIP
-    if (mCurrentImage && (newFileIdx < 0 || newFileIdx >= mImages.size()) && mCurrentImage->isFromZip() && mCurrentImage->getZipData()) {
-        // load the zip again and go on from there
+    // zips only loop if browse filter is disabled; otherwise we could not break out of a zip
+    bool loopZip = DkSettingsManager::param().global().loop && !DkSettingsManager::param().app().browseFilters.contains("*.zip");
+
+    if (!validIndex && !loopZip && mCurrentImage && mCurrentImage->isFromZip() && mCurrentImage->getZipData()) {
+        // browse to the next zipfile or image file (in theory)
+        // fixme: this doesn't really do what you'd want
+        // if skipping backwards it always goes to the first file in the next zip
+        // if skipping forwards it always jumps to last zip or first zip in the directory
         setCurrentImage(QSharedPointer<DkImageContainerT>(new DkImageContainerT(mCurrentImage->getZipData()->getZipFilePath())));
 
         if (newFileIdx >= mImages.size())
@@ -536,9 +529,10 @@ QSharedPointer<DkImageContainerT> DkImageLoader::getSkippedImage(int skipIdx, bo
     }
 #endif
 
-    // this should never happen!
+    // could happen if current dir was deleted; we
+    // don't check status of loadDir() so we can try subfolders
     if (mImages.empty()) {
-        qDebug() << "file list is empty, where it should not be";
+        qWarning() << "unexpected empty file list";
         return imgC;
     }
 
@@ -548,14 +542,13 @@ QSharedPointer<DkImageContainerT> DkImageLoader::getSkippedImage(int skipIdx, bo
 
         while (newFileIdx < 0) // should be hit once
             newFileIdx = mImages.size() + newFileIdx;
-
     }
     // clip to pos1 if skipIdx < -1
-    else if (mTmpFileIdx > 0 && newFileIdx < 0) {
+    else if (currFileIdx > 0 && newFileIdx < 0) {
         newFileIdx = 0;
     }
     // clip to end if skipIdx > 1
-    else if (mTmpFileIdx < mImages.size() - 1 && newFileIdx >= mImages.size()) {
+    else if (currFileIdx < mImages.size() - 1 && newFileIdx >= mImages.size()) {
         newFileIdx = mImages.size() - 1;
     }
     // tell user that there is nothing left to display
@@ -576,8 +569,6 @@ QSharedPointer<DkImageContainerT> DkImageLoader::getSkippedImage(int skipIdx, bo
         return imgC;
     }
 
-    mTmpFileIdx = newFileIdx;
-
     if (newFileIdx >= 0 && newFileIdx < mImages.size())
         imgC = mImages.at(newFileIdx);
 
@@ -833,13 +824,14 @@ void DkImageLoader::setCurrentImage(QSharedPointer<DkImageContainerT> newImg)
 
             mCurrentImage->getLoader()->resetPageIdx();
         }
-        mCurrentImage->receiveUpdates(this, false); // reset updates
+        this->receiveUpdates(false); // reset updates
     }
 
     mCurrentImage = newImg;
 
-    if (mCurrentImage)
-        mCurrentImage->receiveUpdates(this);
+    if (mCurrentImage) {
+        this->receiveUpdates(true);
+    }
 }
 
 void DkImageLoader::reloadImage()
@@ -1464,9 +1456,12 @@ bool DkImageLoader::deleteFile()
 {
     if (mCurrentImage && mCurrentImage->exists()) {
         QString fileName = mCurrentImage->fileName();
-
+        int currFileIdx = findFileIdx(mCurrentImage->filePath(), mImages);
         if (DkUtils::moveToTrash(mCurrentImage->filePath())) {
+            mImages.removeAt(currFileIdx);
             QSharedPointer<DkImageContainerT> imgC = getSkippedImage(1);
+            if (!imgC)
+                imgC = getSkippedImage(0); // deleted from the end
             load(imgC);
             emit showInfoSignal(tr("%1 deleted...").arg(fileName));
             return true;
@@ -1722,62 +1717,46 @@ QFileInfoList DkImageLoader::updateSubFolders(const QString &rootDirPath)
     return files;
 }
 
-int DkImageLoader::getNextFolderIdx(int folderIdx)
+/**
+ * Find the first subfolder that has images
+ * @param fromIdx where to start from
+ * @param next true if check forward
+ * @return -1 or found folder
+ * @see getSkippedImage()
+ */
+int DkImageLoader::getSubFolderIdx(int fromIdx, bool forward) const
 {
-    int nextIdx = -1;
+    int idx = -1;
 
     if (mSubFolders.empty())
-        return nextIdx;
+        return idx;
 
-    // find the first sub folder that has images
-    for (int idx = 1; idx < mSubFolders.size(); idx++) {
-        int tmpNextIdx = folderIdx + idx;
+    bool loop = DkSettingsManager::param().global().loop;
 
-        if (DkSettingsManager::param().global().loop)
-            tmpNextIdx %= mSubFolders.size();
-        else if (tmpNextIdx >= mSubFolders.size())
+    for (int i = 1; i < mSubFolders.size(); i++) {
+        int checkIdx = fromIdx + (forward ? i : -i);
+
+        if (loop) {
+            if (checkIdx < 0)
+                checkIdx += mSubFolders.size();
+            else
+                checkIdx %= mSubFolders.size();
+        }
+
+        if (checkIdx < 0 || checkIdx >= mSubFolders.size())
             return -1;
 
-        QDir cDir = mSubFolders[tmpNextIdx];
+        QDir cDir = mSubFolders[checkIdx];
         QFileInfoList cFiles = getFilteredFileInfoList(cDir.absolutePath(),
                                                        mIgnoreKeywords,
                                                        mKeywords); // this line takes seconds if you have lots of files and slow loading (e.g. network)
         if (!cFiles.empty()) {
-            nextIdx = tmpNextIdx;
+            idx = checkIdx;
             break;
         }
     }
 
-    return nextIdx;
-}
-
-int DkImageLoader::getPrevFolderIdx(int folderIdx)
-{
-    int prevIdx = -1;
-
-    if (mSubFolders.empty())
-        return prevIdx;
-
-    // find the first sub folder that has images
-    for (int idx = 1; idx < mSubFolders.size(); idx++) {
-        int tmpPrevIdx = folderIdx - idx;
-
-        if (DkSettingsManager::param().global().loop && tmpPrevIdx < 0)
-            tmpPrevIdx += mSubFolders.size();
-        else if (tmpPrevIdx < 0)
-            return -1;
-
-        QDir cDir = mSubFolders[tmpPrevIdx];
-        QFileInfoList cFiles = getFilteredFileInfoList(cDir.absolutePath(),
-                                                       mIgnoreKeywords,
-                                                       mKeywords); // this line takes seconds if you have lots of files and slow loading (e.g. network)
-        if (!cFiles.empty()) {
-            prevIdx = tmpPrevIdx;
-            break;
-        }
-    }
-
-    return prevIdx;
+    return idx;
 }
 
 void DkImageLoader::errorDialog(const QString &msg) const
@@ -1866,7 +1845,7 @@ void DkImageLoader::updateCacher(QSharedPointer<DkImageContainerT> imgC)
  * @param keywords if one of these keywords is not in the file name, the file will be ignored.
  * @return QStringList all filtered files of the current directory.
  **/
-QFileInfoList DkImageLoader::getFilteredFileInfoList(const QString &dirPath, QStringList ignoreKeywords, QStringList keywords, QString folderKeywords)
+QFileInfoList DkImageLoader::getFilteredFileInfoList(const QString &dirPath, QStringList ignoreKeywords, QStringList keywords, QString folderKeywords) const
 {
     DkTimer dt;
 
@@ -1999,7 +1978,20 @@ QFileInfoList DkImageLoader::getFilteredFileInfoList(const QString &dirPath, QSt
 
 void DkImageLoader::sort()
 {
-    std::sort(mImages.begin(), mImages.end(), imageContainerLessThanPtr);
+    for (auto &img : qAsConst(mImages))
+        if (!img) {
+            qWarning() << "attempt to sort null image(s) averted";
+            return;
+        }
+
+    bool ascending = DkSettingsManager::param().global().sortDir == DkSettings::sort_ascending;
+
+    auto cmp = DkImageContainer::compareFunc();
+
+    std::sort(mImages.begin(), mImages.end(), cmp);
+    if (!ascending)
+        std::reverse(mImages.begin(), mImages.end());
+
     emit updateDirSignal(mImages);
 }
 
@@ -2233,4 +2225,38 @@ QString DkImageLoader::fileName() const
     return mCurrentImage->fileName();
 }
 
+/**
+ * Connects or disconnects the signals of the current image to corresponding slots.
+ *
+ * @param[in] connectSignals true to connect or false to disconnect
+ */
+void DkImageLoader::receiveUpdates(bool connectSignals)
+{
+    if (!mCurrentImage) {
+        return;
+    }
+
+    DkImageContainerT *currImage = mCurrentImage.data();
+
+    if (currImage == nullptr) {
+        return;
+    }
+
+    // !selected - do not connect twice
+    if (connectSignals && !currImage->isSelected()) {
+        connect(currImage, &DkImageContainerT::errorDialogSignal, this, &DkImageLoader::errorDialog, Qt::UniqueConnection);
+        connect(currImage, &DkImageContainerT::fileLoadedSignal, this, &DkImageLoader::imageLoaded, Qt::UniqueConnection);
+        connect(currImage, &DkImageContainerT::showInfoSignal, this, &DkImageLoader::showInfoSignal, Qt::UniqueConnection);
+        connect(currImage, &DkImageContainerT::fileSavedSignal, this, &DkImageLoader::imageSaved, Qt::UniqueConnection);
+        connect(currImage, &DkImageContainerT::imageUpdatedSignal, this, &DkImageLoader::currentImageUpdated, Qt::UniqueConnection);
+    } else if (!connectSignals) {
+        disconnect(currImage, &DkImageContainerT::errorDialogSignal, this, &DkImageLoader::errorDialog);
+        disconnect(currImage, &DkImageContainerT::fileLoadedSignal, this, &DkImageLoader::imageLoaded);
+        disconnect(currImage, &DkImageContainerT::showInfoSignal, this, &DkImageLoader::showInfoSignal);
+        disconnect(currImage, &DkImageContainerT::fileSavedSignal, this, &DkImageLoader::imageSaved);
+        disconnect(currImage, &DkImageContainerT::imageUpdatedSignal, this, &DkImageLoader::currentImageUpdated);
+    }
+
+    currImage->receiveUpdates(connectSignals);
+}
 }
