@@ -342,8 +342,6 @@ DkMetaDataDock::DkMetaDataDock(const QString &title, QWidget *parent /* = 0 */,
 
     createLayout();
     readSettings();
-
-    QMetaObject::connectSlotsByName(this);
 }
 
 DkMetaDataDock::~DkMetaDataDock()
@@ -389,8 +387,8 @@ void DkMetaDataDock::readSettings()
 void DkMetaDataDock::createLayout()
 {
     mFilterEdit = new QLineEdit(this);
-    mFilterEdit->setObjectName("filter");
     mFilterEdit->setPlaceholderText(tr("Filter"));
+    connect(mFilterEdit, &QLineEdit::textChanged, this, &DkMetaDataDock::onFilterTextChanged);
 
     // create our beautiful shortcut view
     mModel = new DkMetaDataModel(this);
@@ -424,7 +422,7 @@ void DkMetaDataDock::createLayout()
     setWidget(widget);
 }
 
-void DkMetaDataDock::on_filter_textChanged(const QString &filterText)
+void DkMetaDataDock::onFilterTextChanged(const QString &filterText)
 {
     if (!filterText.isEmpty())
         mTreeView->expandAll();
@@ -438,11 +436,10 @@ void DkMetaDataDock::updateEntries()
     for (int idx = 0; idx < nr; idx++)
         getExpandedItemNames(mProxyModel->index(idx, 0, QModelIndex()), mExpandedNames);
 
-    mModel->deleteLater();
-
     if (!mImgC)
         return;
 
+    mModel->deleteLater();
     mModel = new DkMetaDataModel(this);
     mModel->addMetaData(mImgC->getMetaData());
     mProxyModel->setSourceModel(mModel);
@@ -471,7 +468,7 @@ void DkMetaDataDock::setImage(QSharedPointer<DkImageContainerT> imgC)
         // we need to load the thumbnail fresh to guarantee, that we just consider the exif thumb
         // the imgC thumbnail might be created from the image
         mThumb = QSharedPointer<DkThumbNailT>(new DkThumbNailT(imgC->filePath()));
-        connect(mThumb.data(), SIGNAL(thumbLoadedSignal(bool)), this, SLOT(thumbLoaded(bool)));
+        connect(mThumb.data(), &DkThumbNailT::thumbLoadedSignal, this, &DkMetaDataDock::thumbLoaded);
         mThumb->fetchThumb(DkThumbNailT::force_exif_thumb);
     }
 }
@@ -576,7 +573,7 @@ void DkMetaDataSelection::createLayout()
 
     mCbCheckAll = new QCheckBox(tr("Check All"), this);
     mCbCheckAll->setTristate(true);
-    connect(mCbCheckAll, SIGNAL(clicked(bool)), this, SLOT(checkAll(bool)));
+    connect(mCbCheckAll, &QCheckBox::clicked, this, &DkMetaDataSelection::checkAll);
 
     QVBoxLayout *l = new QVBoxLayout(this);
     l->addWidget(scrollArea);
@@ -589,7 +586,7 @@ void DkMetaDataSelection::appendGUIEntry(const QString &key, const QString &valu
     cleanKey = cleanKey.replace(".", " > ");
 
     QCheckBox *cb = new QCheckBox(cleanKey, this);
-    connect(cb, SIGNAL(clicked()), this, SLOT(selectionChanged()));
+    connect(cb, &QCheckBox::clicked, this, &DkMetaDataSelection::selectionChanged);
     mSelection.append(cb);
 
     QString cleanValue = DkUtils::cleanFraction(value);
@@ -753,32 +750,32 @@ void DkMetaDataHUD::createActions()
 
     mActions[action_change_keys] = new QAction(tr("Change Entries"), this);
     mActions[action_change_keys]->setStatusTip(tr("You can customize the entries displayed here."));
-    connect(mActions[action_change_keys], SIGNAL(triggered()), this, SLOT(changeKeys()));
+    connect(mActions[action_change_keys], &QAction::triggered, this, &DkMetaDataHUD::changeKeys);
 
     mActions[action_num_columns] = new QAction(tr("Number of Columns"), this);
     mActions[action_num_columns]->setStatusTip(tr("Select the desired number of columns."));
-    connect(mActions[action_num_columns], SIGNAL(triggered()), this, SLOT(changeNumColumns()));
+    connect(mActions[action_num_columns], &QAction::triggered, this, &DkMetaDataHUD::changeNumColumns);
 
     mActions[action_set_to_default] = new QAction(tr("Set to Default"), this);
     mActions[action_set_to_default]->setStatusTip(tr("Reset the metadata panel."));
-    connect(mActions[action_set_to_default], SIGNAL(triggered()), this, SLOT(setToDefault()));
+    connect(mActions[action_set_to_default], &QAction::triggered, this, &DkMetaDataHUD::setToDefault);
 
     // orientations
     mActions[action_pos_west] = new QAction(tr("Show Left"), this);
     mActions[action_pos_west]->setStatusTip(tr("Shows the Metadata on the Left"));
-    connect(mActions[action_pos_west], SIGNAL(triggered()), this, SLOT(newPosition()));
+    connect(mActions[action_pos_west], &QAction::triggered, this, &DkMetaDataHUD::newPosition);
 
     mActions[action_pos_north] = new QAction(tr("Show Top"), this);
     mActions[action_pos_north]->setStatusTip(tr("Shows the Metadata at the Top"));
-    connect(mActions[action_pos_north], SIGNAL(triggered()), this, SLOT(newPosition()));
+    connect(mActions[action_pos_north], &QAction::triggered, this, &DkMetaDataHUD::newPosition);
 
     mActions[action_pos_east] = new QAction(tr("Show Right"), this);
     mActions[action_pos_east]->setStatusTip(tr("Shows the Metadata on the Right"));
-    connect(mActions[action_pos_east], SIGNAL(triggered()), this, SLOT(newPosition()));
+    connect(mActions[action_pos_east], &QAction::triggered, this, &DkMetaDataHUD::newPosition);
 
     mActions[action_pos_south] = new QAction(tr("Show Bottom"), this);
     mActions[action_pos_south]->setStatusTip(tr("Shows the Metadata at the Bottom"));
-    connect(mActions[action_pos_south], SIGNAL(triggered()), this, SLOT(newPosition()));
+    connect(mActions[action_pos_south], &QAction::triggered, this, &DkMetaDataHUD::newPosition);
 }
 
 void DkMetaDataHUD::loadSettings()
@@ -826,6 +823,7 @@ QStringList DkMetaDataHUD::getDefaultKeys() const
     keyValues.append("Exif.Image.DateTime");
     keyValues.append("Exif.Image.ImageDescription");
 
+    keyValues.append("Exif.Photo.UserComment");
     keyValues.append("Exif.Photo.ISO");
     keyValues.append("Exif.Photo.FocalLength");
     keyValues.append("Exif.Photo.ExposureTime");
@@ -1099,8 +1097,8 @@ void DkMetaDataHUD::changeKeys()
     QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, this);
     buttons->button(QDialogButtonBox::Ok)->setText(tr("&OK"));
     buttons->button(QDialogButtonBox::Cancel)->setText(tr("&Cancel"));
-    connect(buttons, SIGNAL(accepted()), dialog, SLOT(accept()));
-    connect(buttons, SIGNAL(rejected()), dialog, SLOT(reject()));
+    connect(buttons, &QDialogButtonBox::accepted, dialog, &QDialog::accept);
+    connect(buttons, &QDialogButtonBox::rejected, dialog, &QDialog::reject);
 
     QVBoxLayout *layout = new QVBoxLayout(dialog);
     layout->addWidget(selWidget);
@@ -1164,7 +1162,6 @@ DkCommentWidget::DkCommentWidget(QWidget *parent /* = 0 */, Qt::WindowFlags /* =
 {
     setMaximumSize(220, 150);
     createLayout();
-    QMetaObject::connectSlotsByName(this);
 }
 
 void DkCommentWidget::createLayout()
@@ -1183,24 +1180,25 @@ void DkCommentWidget::createLayout()
         + QString("QScrollBar::add-line:vertical, QScrollBar::sub-line:vertical {height: 0;}");
 
     mCommentLabel = new DkCommentTextEdit(this);
-    mCommentLabel->setObjectName("CommentLabel");
     mCommentLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     mCommentLabel->setStyleSheet(scrollbarStyle + mCommentLabel->styleSheet());
     mCommentLabel->setToolTip(tr("Enter your notes here. They will be saved to the image metadata."));
+    connect(mCommentLabel, &DkCommentTextEdit::textChanged, this, &DkCommentWidget::onCommentLabelTextChanged);
+    connect(mCommentLabel, &DkCommentTextEdit::focusLost, this, &DkCommentWidget::onCommentLabelFocusLost);
 
     QPushButton *saveButton = new QPushButton(this);
-    saveButton->setObjectName("saveButton");
     saveButton->setFlat(true);
     saveButton->setIcon(DkImage::loadIcon(":/nomacs/img/save.svg", QSize(), DkSettingsManager::param().display().hudFgdColor));
     saveButton->setToolTip(tr("Save Note (CTRL + ENTER)"));
     saveButton->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Return));
+    connect(saveButton, &QPushButton::clicked, this, &DkCommentWidget::onSaveButtonClicked);
 
     QPushButton *cancelButton = new QPushButton(this);
-    cancelButton->setObjectName("cancelButton");
     cancelButton->setFlat(true);
     cancelButton->setIcon(DkImage::loadIcon(":/nomacs/img/trash.svg", QSize(), DkSettingsManager::param().display().hudFgdColor));
     cancelButton->setToolTip(tr("Discard Changes (ESC)"));
     cancelButton->setShortcut(QKeySequence(Qt::Key_Escape));
+    connect(cancelButton, &QPushButton::clicked, this, &DkCommentWidget::onCancelButtonClicked);
 
     QWidget *titleWidget = new QWidget(this);
     QHBoxLayout *titleLayout = new QHBoxLayout(titleWidget);
@@ -1263,25 +1261,25 @@ void DkCommentWidget::saveComment()
     }
 }
 
-void DkCommentWidget::on_CommentLabel_textChanged()
+void DkCommentWidget::onCommentLabelTextChanged()
 {
     mTextEdited = text() != mOldText;
     if (mTextEdited)
         emit commentEditedSignal();
 }
 
-void DkCommentWidget::on_CommentLabel_focusLost()
+void DkCommentWidget::onCommentLabelFocusLost()
 {
     // We don't want to do anything when changing focus
 }
 
-void DkCommentWidget::on_saveButton_clicked()
+void DkCommentWidget::onSaveButtonClicked()
 {
     saveComment();
     mCommentLabel->clearFocus();
 }
 
-void DkCommentWidget::on_cancelButton_clicked()
+void DkCommentWidget::onCancelButtonClicked()
 {
     resetComment();
 }
